package com.qmth.sop.business.entity;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.qmth.sop.common.base.BaseEntity;
import com.qmth.sop.common.enums.TFCustomTypeEnum;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/**
 * <p>
 * sop表
 * </p>
 *
 * @author wangliang
 * @since 2023-08-01
 */
@ApiModel(value = "TBSopInfo对象", description = "sop表")
public class TBSopInfo extends BaseEntity implements Serializable {

    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "crm单号")
    private String crmNo;

    @ApiModelProperty(value = "sop单号")
    private String sopNo;

    @ApiModelProperty(value = "服务单元id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long serviceId;

    @ApiModelProperty(value = "客户id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long customId;

    @ApiModelProperty(value = "学院名称")
    private String collegeName;

    @ApiModelProperty(value = "产品id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long productId;

    @ApiModelProperty(value = "区域负责人id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long regionUserId;

    @ApiModelProperty(value = "阅卷负责人id")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long cloudMarkUserId;

    @ApiModelProperty(value = "流程类型，OFFICE_SOP_FLOW：教务处SOP，CLOUD_MARK_SOP_FLOW：研究生SOP")
    private TFCustomTypeEnum type;

    public TBSopInfo() {

    }

    public TBSopInfo(String crmNo, Long serviceId, Long customId, String collegeName, Long productId, Long regionUserId, Long cloudMarkUserId, TFCustomTypeEnum type, Long userId) {
        this.crmNo = crmNo;
        this.serviceId = serviceId;
        this.customId = customId;
        this.collegeName = collegeName;
        this.productId = productId;
        this.regionUserId = regionUserId;
        this.cloudMarkUserId = cloudMarkUserId;
        this.type = type;
        setCreateId(userId);
        setCreateTime(System.currentTimeMillis());
    }

    public String getCrmNo() {
        return crmNo;
    }

    public void setCrmNo(String crmNo) {
        this.crmNo = crmNo;
    }

    public String getSopNo() {
        return sopNo;
    }

    public void setSopNo(String sopNo) {
        this.sopNo = sopNo;
    }

    public Long getServiceId() {
        return serviceId;
    }

    public void setServiceId(Long serviceId) {
        this.serviceId = serviceId;
    }

    public Long getCustomId() {
        return customId;
    }

    public void setCustomId(Long customId) {
        this.customId = customId;
    }

    public String getCollegeName() {
        return collegeName;
    }

    public void setCollegeName(String collegeName) {
        this.collegeName = collegeName;
    }

    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }

    public Long getRegionUserId() {
        return regionUserId;
    }

    public void setRegionUserId(Long regionUserId) {
        this.regionUserId = regionUserId;
    }

    public Long getCloudMarkUserId() {
        return cloudMarkUserId;
    }

    public void setCloudMarkUserId(Long cloudMarkUserId) {
        this.cloudMarkUserId = cloudMarkUserId;
    }

    public TFCustomTypeEnum getType() {
        return type;
    }

    public void setType(TFCustomTypeEnum type) {
        this.type = type;
    }
}
